/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */
package gov.nist.atlas;

import gov.nist.atlas.type.ATLASType;
import gov.nist.atlas.type.ChildrenType;
import gov.nist.atlas.util.ATLASElementSet;
import gov.nist.atlas.util.Sortable;

/**
 * Completely re-written for 2.0 beta 4: what was previously called Children
 * is now called AnnotationChildren.
 *
 * @version $Revision: 1.20 $
 * @author Christophe Laprun
 */
public interface Children extends ATLASElement, Sortable {
  /**
   * NOT YET IMPLEMENTED!
   * @param resultElementType
   * @return
   *
   * @since 2.0 beta 4
   */
  ATLASElement consolidateAs(ATLASType resultElementType);

  /**
   * Retrieves the ChildrenType associated with this Children element.
   *
   * @return the associated ChildrenType
   *
   * @since 2.0 beta 4
   */
  ChildrenType getChildrenType();

  /**
   * Retrieves the ATLASType of elements which can be contained in this Children
   * element.
   *
   * @return the ATLASType of elements which can be contained in this Children
   * element
   *
   * @since 2.0 beta 4
   */
  ATLASType getContainedElementsType();

  /**
   * Retrieves the elements contained in this Children.
   *
   * @return a possibly empty ATLASElementSet of the contained ATLASElements
   * @since 2.0 beta 5
   */
  ATLASElementSet getContainedElements();

  /**
   * Adds (if possible) the elements contained in the specified ATLASElementSet
   * to this Children element.
   *
   * FIX-ME: bad error handling!!
   *
   * @param children the elements to be added to this Children element
   * @param expectedElementsClass the expected ATLASClass of the elements to be
   *        added
   * @return <code>true</code> if the addition was successful, <code>false</code>
   *         otherwise
   * @throws ATLASAccessException
   */
  boolean addToSubordinateSet(ATLASElementSet children, ATLASClass expectedElementsClass) throws ATLASAccessException;
}
