/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */
package gov.nist.atlas.impl;

import gov.nist.atlas.ATLASClass;
import gov.nist.atlas.ATLASElement;
import gov.nist.atlas.Annotation;
import gov.nist.atlas.Region;
import gov.nist.atlas.spi.TypeImplementationDelegate;
import gov.nist.atlas.type.ATLASType;
import gov.nist.atlas.type.AbstractATLASType;
import gov.nist.atlas.type.ChildrenType;
import gov.nist.maia.MAIAScheme;

import java.util.Iterator;

/**
 * An implementation of ChildrenType.
 *
 * @version $Revision: 1.3 $
 * @author Christophe Laprun
 *
 * @since 2.0 beta 4
 */
public class ChildrenTypeImpl extends AbstractATLASType implements ChildrenType {
  public ChildrenTypeImpl(ATLASType superType, String name, MAIAScheme scheme, TypeImplementationDelegate delegate) {
    super(superType, name, scheme, delegate);
  }

  public ATLASClass getATLASClass() {
    return ATLASClass.CHILDREN;
  }

  public boolean isParentValid(ATLASElement parent) {
    return parent instanceof Annotation || parent instanceof Region;
  }

  public ATLASType getContainedElementsType() {
    Iterator types = getContainedTypesInSubordinateSets();
    if (types.hasNext())
      return (ATLASType) types.next();
    throw new IllegalArgumentException(this + " is not a valid children type!");
  }

  public ATLASType getConsolidatedElementType() {
    return consolidatedElementType;
  }

  public void setConsolidatedElementType(ATLASType type) {
    consolidatedElementType = type;
  }

  public boolean isOrderMeaningful() {
    return orderMeaningful;
  }

  public void setOrderMeaningful(boolean orderMeaningful) {
    this.orderMeaningful = orderMeaningful;
  }

  public boolean isSortable() {
    return false;
  }

  private ATLASType consolidatedElementType;
  private boolean orderMeaningful;
}
