/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.impl;

import gov.nist.atlas.ATLASClass;
import gov.nist.atlas.ATLASElement;
import gov.nist.atlas.Annotation;
import gov.nist.atlas.spi.TypeImplementationDelegate;
import gov.nist.atlas.type.ATLASType;
import gov.nist.atlas.type.AbstractATLASType;
import gov.nist.atlas.type.ContentType;
import gov.nist.maia.MAIAScheme;

/**
 * An implementation of ContentType.
 *
 * @version $Revision: 1.7 $
 * @author Christophe Laprun
 */
public class ContentTypeImpl extends AbstractATLASType implements ContentType {
  public ContentTypeImpl(ATLASType superType, String name, MAIAScheme scheme, TypeImplementationDelegate delegate, boolean hasAlignedRegion) {
    super(superType, name, scheme, delegate);
    this.hasAlignedRegion = hasAlignedRegion;
  }

  public ATLASClass getATLASClass() {
    return ATLASClass.CONTENT;
  }

  public boolean isParentValid(ATLASElement parent) {
    return parent instanceof Annotation;
  }

  public boolean hasAlignedRegion() {
    return hasAlignedRegion;
  }

  public void setAlignedRegion(boolean hasAlignedRegion) {
    this.hasAlignedRegion = hasAlignedRegion;
  }

  public String getRoleForAlignedRegion() {
    return (String) getRolesForRequiredChildrenWith(ATLASClass.REGION).get(0); // FIX-ME?
  }

  private boolean hasAlignedRegion;
}



