/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.impl;

import gov.nist.atlas.ATLASClass;
import gov.nist.atlas.ATLASElement;
import gov.nist.atlas.Feature;
import gov.nist.atlas.Parameter;
import gov.nist.atlas.io.xml.AIFExportConstants;
import gov.nist.atlas.spi.ImplementationDelegate;
import gov.nist.atlas.type.ATLASType;
import gov.nist.atlas.type.FeatureType;
import gov.nist.atlas.util.ATLASElementSet;
import gov.nist.atlas.util.RoleIdentifiedFeature;
import gov.nist.atlas.util.RoleIdentifiedParameter;


/**
 * @version $Revision: 1.31 $
 * @author Chris Laprun
 * @author Sylvain Pajot
 */
public class FeatureImpl extends ATLASElementImpl implements Feature {
  protected FeatureImpl(ATLASType type, ATLASElement parent, ImplementationDelegate delegate) {
    super(type, parent, delegate);
  }

  public final FeatureType getFeatureType() {
    return (FeatureType) getATLASType();
  }

  public final boolean isTypeValid(ATLASType type) {
    return super.isTypeValid(type) && (type instanceof FeatureType);
  }

  public void toAIFBuffer(StringBuffer sb, String indent, String role, ATLASElement context) {
    sb.append(indent).append(AIFExportConstants.FEATURE_S)
        .append(getATLASType().getName()).append(AIFExportConstants.ROLE_ATT)
        .append(role).append(AIFExportConstants.CLOSE);

    subordinatesToAIFBuffer(sb, newIndent(indent), this);

    sb.append(indent).append(AIFExportConstants.FEATURE_E);
  }

  public void initContainedElementsWith(RoleIdentifiedFeature[] features, RoleIdentifiedParameter[] parameters) {
    // WARNING
    // only fixed elements are passed as arguments in the initWith() method
    // temporary variables for elements addition
    int numberOfElements, i;
    RoleIdentifiedParameter iteParameter;
    RoleIdentifiedFeature iteFeature;
    // Parameters addition
    if (parameters != null) {
      numberOfElements = parameters.length;
      for (i = 0; i < numberOfElements; i++) {
        iteParameter = parameters[i];
        setSubordinateWithRole(iteParameter.getElement(), iteParameter.getRole());
      }
    }
    // Features addition
    if (features != null) {
      numberOfElements = features.length;
      for (i = 0; i < numberOfElements; i++) {
        iteFeature = features[i];
        setSubordinateWithRole(iteFeature.getElement(), iteFeature.getRole());
      }
    }
  }

  public ATLASClass getATLASClass() {
    return ATLASClass.FEATURE;
  }

  public Feature getFeatureWithRole(String role) {
    return (Feature) getSubordinateWithRole(role);
  }

  public ATLASElementSet getAllFeatures() {
    return getAllChildrenWith(ATLASClass.FEATURE);
  }

  public boolean setFeatureWithRole(Feature feature, String role) {
    return setSubordinateWithRole(feature, role);
  }

  public boolean setValueOfParameterWithRole(String value, String role) {
    Parameter tempParameter = (Parameter) getSubordinateWithRole(role);
    if (tempParameter != null) {
      return tempParameter.setValue(value);
    }
    return false;
  }

  public String getStringValueOfParameterWithRole(String role) {
    return getParameterWithRole(role).getValueAsString();
  }

  public Object getObjectValueOfParameterWithRole(String role) {
    return getParameterWithRole(role).getValueAsObject();
  }

  public ATLASElementSet getAllParameters() {
    return getAllChildrenWith(ATLASClass.PARAMETER);
  }

  public Parameter getParameterWithRole(String role) {
    return (Parameter) getSubordinateWithRole(role);
  }
}