/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.io.xml;

import gov.nist.atlas.Corpus;

import java.io.File;
import java.io.Writer;
import java.net.URL;


/**
 * This class is the implementation of the ATLASExport interface for AIF
 * purposes.
 * <BR>It writes the corpus in the AIF format, in the associated output file.
 *
 * @author Sylvain Pajot, Chris Laprun
 * @version $Revision: 1.13 $
 * @see gov.nist.atlas.io.ATLASExport
 */
public class AIFXMLExport extends XMLExport {
  public AIFXMLExport() {
    this((URL) null);
  }

  public AIFXMLExport(File file) {
    super(file);
  }

  public AIFXMLExport(URL url) {
    super(url);
  }

  public void setDestinationURL(URL destination) {
    this.url = destination;
  }

  protected void write(Corpus corpus, Writer writer) {
    try {
      writer.write(AIFExportConstants.XML_INFO);
      StringBuffer sb = new StringBuffer(10000);
      corpus.toAIFBuffer(sb, AIFExportConstants.INDENT, "", null);
      writer.write(sb.toString());
      writer.flush();
      writer.close();
    } catch (Exception e) {
      System.err.println("AIFXMLExport.write: ");
      e.printStackTrace();
    }
  }
}



