/*
 * ATLAS
 * Architecture and Tools for Linguistic Analysis Systems
 * Author: Chris Laprun, Sylvain Pajot
 *
 * This software was developed at the National Institute of Standards and Technology by
 * employees of the Federal Government in the course of their official duties.  Pursuant to
 * Title 17 Section 105 of the United States Code this software is not subject to copyright
 * protection within the United States and is in the public domain. jATLAS is
 * an experimental system.  NIST assumes no responsibility whatsoever for its use by any party.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS."  With regard to this software, NIST MAKES NO EXPRESS
 * OR IMPLIED WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING MERCHANTABILITY,
 * OR FITNESS FOR A PARTICULAR PURPOSE.
 */

package gov.nist.atlas.util;

import gov.nist.atlas.ATLASClass;
import gov.nist.atlas.ATLASElement;
import gov.nist.atlas.type.ATLASType;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

/**
 * A MapATLASElementSet which containing elements can be sorted.
 *
 * @version $Revision: 1.5 $
 * @author Christophe Laprun
 */
public class SortableMapATLASElementSet extends MapATLASElementSet {

  /**
   * Constructs a new, empty SortableMapATLASElementSet with a default guarding
   * ATLASType and capacity
   */
  public SortableMapATLASElementSet(ATLASType type, int size) {
    this(type, size, null);
  }

  /**
   * Constructs a new, empty SortableMapATLASElementSet with a default guarding
   * ATLASClass and capacity
   */
  public SortableMapATLASElementSet(ATLASClass clazz, int size) {
    this(clazz, size, null);
  }

  public SortableMapATLASElementSet(Object guard, int size, ATLASElementSetProperties properties) {
    super(guard, size, properties);
  }

  public Iterator iterator() {
    return sortable.iterator();
  }

  public void clear() {
    super.clear();
    sortable.clear();
  }

  public boolean add(ATLASElement element) {
    if (super.add(element)) {
      sortable.add(element);
      return true;
    }
    return false;
  }

  public void sort() {
    Collections.sort(sortable);
  }

  public void sort(Comparator comparator) {
    Collections.sort(sortable, comparator);
  }

  public boolean remove(ATLASElement element) {
    if (super.remove(element)) {
      sortable.remove(element);
      return true;
    }
    return false;
  }

  protected void initContainer(int size, ATLASElementSetProperties properties) {
    super.initContainer(size, properties);
    if (properties.isBooleanPropertySet(ATLASElementSetProperties.HEAVY_COUNT_CHANGES))
      sortable = new LinkedList();
    else
      sortable = new ArrayList();
  }

  private List sortable;
}
